@@ -1,7 +1,8 @@
 
 from . import (
     database_info,
-    database
+    database,
+    file
 )
 
 from .database import (
@@ -10,4 +11,11 @@ from .database import (
 
 from .database_info import (
     DbConnInfoStore
+)
+
+from .file import (
+    File,
+    Csv,
+    Sas,
+    Excel
 )
\ No newline at end of file
